@@ -8,12 +8,12 @@
 #pragma once
 
 #include "net/SecurityLevel.h"
-#include "net/SocketException.h"
 #include "net/TCPSocket.h"
 
 #include <memory>
 #include <mutex>
 
+class Event;
 class IEventQueue;
 class SocketMultiplexer;
 class ISocketMultiplexerJob;
@@ -80,9 +80,9 @@ private:
   void disconnect();
   bool verifyCertFingerprint(const QString &FingerprintDatabasePath) const;
 
-  ISocketMultiplexerJob *serviceConnect(ISocketMultiplexerJob *, bool, bool, bool);
+  ISocketMultiplexerJob *serviceConnect(ISocketMultiplexerJob *const socket, bool, bool, bool);
 
-  ISocketMultiplexerJob *serviceAccept(ISocketMultiplexerJob *, bool, bool, bool);
+  ISocketMultiplexerJob *serviceAccept(ISocketMultiplexerJob *const socket, bool, bool, bool);
 
   void handleTCPConnected(const Event &event);
 
